基于panda3d引擎开发的，帮助儿童学习3d编程的模块。

#创建一个三维程序，带有xyz轴
from xdk import *
x=XKD() #创建一个程序
x.run() #运行程序

#创建3d线条
from xkd import *
x=XKD()
p=Pen(x) #创建一个3d画笔
p.color(Color.tan) #设置线条颜色为tan
p.size(8) #设置线条粗细
p.moveTo(0,0,0) #画笔移到坐标
p.lineTo(3,3,3) #绘制线条到坐标
p.update() #更新线条
x.run()

#动态更新线条的形状
from xkd import *

x=XKD()#创建程序
p=Pen(x) #画笔

top=[2,2,1] #线段顶部的顶点坐标
md=1#顶点移动方向 (move direction)
step=0.05#移动步长

def up():#自定义的帧更新函数
    global md
    p.clear()#清空
    if md==1:#向上移动状态
        c=Color.yellow#黄色
        if top[2]>5:#超过最高点
            md*=-1#移动反向
    else:#向下移动状态
        c=Color.pink#粉色
        if top[2]<1:#超过最低点
            md*=-1#移动反向
    top[2]+=step*md#顶部顶点的移动
    
    p.color(c)  # 设置线条颜色
    p.size(8)#设置线条粗细
    p.moveTo(2, 2, 0)#线条的起点
    p.lineTo(top[0],top[1],top[2])#线条的终点
    p.update()#更新线条

x.update=up #设置更新函数为自定义的up

x.run()#运行程序

